@@ -3,8 +3,8 @@
 
 __author__ = "Timo Stollenwerk (timo@zmag.de)"
 __license__ = "GNU General Public License (GPL)"
-__revision__ = "$Rev: 246 $"
-__date__ = "$Date: 2008-03-09 11:51:28 +0100 (So, 09 Mrz 2008) $"
+__revision__ = "$Rev: 257 $"
+__date__ = "$Date: 2008-03-11 22:00:09 +0100 (Di, 11 Mrz 2008) $"
 __URL__ = "$URL: https://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/docbook2sla.py $"
 
 import os, sys
@@ -92,31 +92,21 @@ class DocBook2Sla(object):
 
         LOG.info("syncronize(%s, %s, output_filename=%s, validate=%s" % (docbookfn, scribusfn, output_filename, validate))
 
+        # fetch synconize stylesheet
+        xsl_syncronize = os.path.abspath(os.path.join(dirname, 'xsl', 'syncronize.xsl'))
+        if not os.path.exists(xsl_syncronize):
+            raise IOError('%s does not exist' % xsl_syncronize)
+
         # validate input files
         if validate:
             try:
-                LOG.info('validate docbook: %s' % self.validate(docbookfn))
-                LOG.info('validate scribus: %s' % self.validate(scribusfn))
+                LOG.info('syncronize(): validate docbook: %s' % self.validate(docbookfn))
+                LOG.info('syncronize(): validate scribus: %s' % self.validate(scribusfn))
             except:
-                print >>sys.stderr, 'Error validating %s and %s' % (docbookfn, scribusfn)
+                print >>sys.stderr, 'syncronize(): Error validating %s and %s' % (docbookfn, scribusfn)
                 raise
 
-        # generate id : content.xml -> content.id.xml
-        #docbook_with_ids = self.transform(docbookfn, self.xsl_generateid)
-
-        #if _debug:
-        #    LOG.info("DEBUG: docbook_with_ids written to '%s'" % docbook_with_ids)
-            #return open(docbook_with_ids, 'r').read()
-
-        # docbook2pageobject : 01_content.id.xml -> pageobjects.xml
-        scribus_pageobjects = self.transform(docbookfn, self.xsl_docbook2pageobject)
-
-        if _debug:
-            LOG.info("DEBUG: scribus_pageobjects written to '%s'" % scribus_pageobjects)
-            #return open(scribus_pageobjects, 'r').read()
-
-        # wrapper : pageobjects.xml + clean134.sla -> output.sla
-        output = self.transform(scribusfn, self.xsl_wrapper, secondinputfn=scribus_pageobjects)
+        output = self.transform(scribusfn, xsl_syncronize, secondinputfn=docbookfn)
 
         if _debug:
             LOG.info("DEBUG: output written to '%s'" % output)
