@@ -29,7 +29,7 @@ class DocBook2PageobjectTestCase(unittest.TestCase):
 
         # transform
         self.outputfn = self.d2s.transform('tests/data/xml/article+id.xml',
-                                      xsl_docbook2pageobject)
+                                           xsl_docbook2pageobject)
 
         # set output
         self.output = open(self.outputfn, 'r').read()
@@ -41,6 +41,19 @@ class DocBook2PageobjectTestCase(unittest.TestCase):
         count_pageobjects = self.outputtree.xpath("count(//PAGEOBJECT)")
         self.assertEqual(count_pageobjects, 4.0)
 
+    def testSimplePageobject(self):
+        """ Test that the simple pageobjects have the correct ids """
+
+        first_pageobject = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id002'])")
+        self.assertEqual(first_pageobject, 1.0)
+
+        second_pageobject = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id003'])")
+        self.assertEqual(second_pageobject, 1.0)
+
+        third_pageobject = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id004'])")
+        self.assertEqual(third_pageobject, 1.0)
+
+
     def testComplexPageobject(self):
         """ Test that the complex pageobject has the correct number of ITEXT nodes """
 
@@ -60,6 +73,11 @@ class DocBook2PageobjectTestCase(unittest.TestCase):
 
         self.assertEqual(True, xmlschema.validate(self.outputtree), self.output)
 
+    def testNoUnvalidIds(self):
+        """ Test that unique ids are in the anname attribute """
+        count_pageobjects = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME!=''])")
+        self.assertEqual(count_pageobjects, 4.0)
+
 def test_suite():
     suite = unittest.TestLoader().loadTestsFromTestCase(DocBook2PageobjectTestCase)
     unittest.TextTestRunner(verbosity=2).run(suite)
